<?php

namespace Drupal\sitemap\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Routing\RouteSubscriberBase;
use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;

/**
 * Alter routes provided by this module, i.e.: to add a custom sitemap path.
 */
class RouteSubscriber extends RouteSubscriberBase {

  /**
   * A configuration object for the sitemap settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Constructs a RouteSubscriber object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   A configuration object factory.
   */
  public function __construct(ConfigFactoryInterface $configFactory) {
    $this->config = $configFactory->get('sitemap.settings');
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection) {
    $path = $this->config->get('path');
    if (\is_string($path)) {
      // Create the route to display the sitemap at.
      $collection->add('sitemap.page', new Route($path, [
        '_controller' => '\Drupal\sitemap\Controller\SitemapController::buildSitemap',
        '_title_callback' => '\Drupal\sitemap\Controller\SitemapController::getTitle',
      ], [
        '_permission' => 'access sitemap',
      ]));
    }
  }

}
